clear all
close all
tic

raw=load('Timken_data.txt');
Model_Fct=raw(:,1); d_Fct=raw(:,2)*1e-3; Ca1_Fct=raw(:,3)*1e3;
db_Fct=raw(:,4)*1e-3; H_Fct=raw(:,5)*1e-3;
E_Fct=raw(:,6)*1e-3; D_Fct=raw(:,7)*1e-3;
R_race_Fct=(mean(raw(:,4:7)')')*(0.5e-3);


%_________________________________________________________________________


Ey=210e9;          % Young's Modulus of the tested material in Pa 
poisson=.3;        % Poisson Ratio of tested material 
V40=46; V100=8.5; % For Mobil SHC 625 Gear Oil
COF=0.0018; 
k=46.6;            % Thermal Conductivity of Material (W/m-K) - Steel 
rho=7810;          % Material Density (kg/m^3) - Steel 
Cp=475;            % Specific Heat of Material (J/kg-K) - Steel 

k_lub=0.140;       % thermal conductivity of oil (W/m-K), Table A-13 of Cengel 
Cp_lub=2000;       % specific heat of oil (J/kg-K) 
rho_lub=905.75;    % Density of Lubricant (kg/m^3) 

%_________________________________________________________________________

uu=26;
Ca1=Ca1_Fct(uu); dm=d_Fct(uu); Model=Model_Fct(uu);
Dbb=2*R_race_Fct(uu); 

LL=(62.1e-3)*(dm/0.3); % the length of the rollers (meters)
rr=(23.5866e-3)*(dm/0.3); % the radius of the rollers (meters)
N=23;


%Tfct=40;
Tfct=20:10:300;  
%FaFct=Ca1/1; 
dF=1e-2; FaFct=Ca1*(dF:dF:1); 
%Speed_Fct=10000;
Speed_Fct=1000:500:15000;  %Speed_Fct=100:100:15000; 

ctx1=length(Tfct); ctx2=length(FaFct); ctx3=length(Speed_Fct);
ctx=ctx1*ctx2*ctx3; ctxx=0; ctxx100=0;

L10dat=zeros(ctx,1); HD_dat=zeros(ctx,2); PCdat=zeros(ctx,1);


%_________________________________________________________________________

%T=20:2:300C, load ratio (2%:100%)*C, Speed=100:15000 RPM

for ii=1:ctx1
    T_lub0=Tfct(ii);
    for jj=1:ctx2
        Fa=FaFct(jj); Fr=0;
        for jj=1:ctx3
            RPM=Speed_Fct(jj);
            ctxx=ctxx+1;
            if floor(ctxx*100/ctx)>ctxx100
                ctxx100=ctxx100+1;
                display([num2str(ctxx100) '/100']);
            end





%_________________________________________________________________________



P=(1.2*Fr)+(Fa); PCdat(ctxx)=P/Ca1;
Rp=rr/2; LL_p=LL/2;
Eyr=Ey/(1-(poisson^2)); 
W=P/N;

TD=k/(rho*Cp); % Thermal Diffusivity (m2/s) 
V=(RPM/60)*(Dbb*pi);
b=sqrt((4*W*Rp)/(pi*LL_p*Eyr));
kellip=LL_p/b;
del=0.319*(W/(LL_p*Eyr))*((2/3)+(log(4*rr*(Dbb/2)/(b^2))));
Kh=del/(W/(b*LL));
qq=COF*W*V/(4*b*LL);
L=V*b/(2*TD); % Peclet Number (dimensionless)             if L<0.1 
if L>5
    Tf=(1.064*qq/k)*sqrt(TD*b/V);
else
    Tf=0;
    display(['Low Peclet Numbers!!!']);
end
Tf=Tf+T_lub0;
VcSt0=(ViscFct(Tf,V40,V100));
PVC=((0.965*(log10(VcSt0)))+0.6)*(1e-8);
Vpas=VcSt0*rho_lub*(1e-6); 
H0HD=Rp*3.63*((V*Vpas/(Eyr*Rp))^0.68)*((PVC*Eyr)^0.49)*((P/(Eyr*(Rp^2)))^-0.073)*(1-(exp(-0.68*kellip))); 
HcHD=Rp*2.69*((V*Vpas/(Eyr*Rp))^0.67)*((PVC*Eyr)^0.53)*((P/(Eyr*(Rp^2)))^-0.067)*(1-(0.61*exp(-0.73*kellip))); 


%_________________________________________________________________________
% Calculate the L10 Life (R=90)
%_________________________________________________________________________

R=90; % Percentage to survive till L10;
a1=(4.26*((log(100/R))^(2/3)))+0.05;
a2=1.0; % Material factor, already 1.0

%X=(10.^(0:6))'; Y=[1.0 0.57 0.325 0.18 0.1 0.055 0.03]';
% Load Factor: Cl = X^(-0.25), where X = Pr in Newtons

kinvisc=(ViscFct(T_lub0,V40,V100));
if Fr>(0.55*Fa)
    display('Two Much Radial Load');
end
Cg=1;
Cl=P^(-0.25);
Cj=1;
Cs=sqrt(RPM);
Cv=1.6*sqrt(kinvisc);
Cgr=1; %Cgr=0.79;

A=a1*a2*Cg*Cl*Cj*Cs*Cv*Cgr;
L10=A*((Ca1/P)^(10/3))*(1e6);

L10dat(ctxx)=L10; HD_dat(ctxx,1)=H0HD; HD_dat(ctxx,2)=HcHD;


%_________________________________________________________________________

        end
    end
end

y=log10(L10dat);
A=[(PCdat.^0) (PCdat.^(3/10)) (log((HD_dat(:,2))*(1e0)))];
AtA=inv((A')*A); b=AtA*((A')*y);
y2=(b(1)*A(:,1))+(b(2)*A(:,2))+(b(3)*A(:,3));
R2=R2fct(y,y2);

runtime=toc;

save Sim_Dat